#include <algorithm>
#include <array>
#include <cassert>
#include <climits>
#include <cmath>
#include <iomanip>
#include <iostream>
#include <map>
#include <random>
#include <unordered_map>
#include <vector>
#include "circle.h"
#include "circle.cpp"

static const int MAX_CALLS = 100000;
static const double MAX_COORD = 5e5;
static const double MAX_RADIUS = 5e5;

static int calls = 0;
static int __Q = 0;
static int __K;

void check_value(double val, const char* name) {
    if(std::isnan(val) || std::isinf(val) || std::abs(val) > MAX_COORD) {
        std::cerr << "Invalid " << name << " value: " << val << "\n";
        exit(0);
    }
}

static std::vector<std::tuple<double, double, double>> circles;
static std::vector<std::tuple<double, double, double>> given_circles;

void answer(double cen_x, double cen_y, double radius) {
    cout<<cen_x<<" "<<cen_y<<" "<<radius<<endl;
    calls++;
    if(calls > __K) {
        std::cerr << "Too many answer() calls\n";
        exit(0);
    }

    check_value(cen_x, "x");
    check_value(cen_y, "y");
    check_value(radius, "radius");

    if(radius <= 0) {
        std::cerr << "Invalid radius: " << radius << "\n";
        std::cout << -2 << "\n";
        exit(0);
    }

    circles.push_back({cen_x, cen_y, radius});
}

std::pair<double, double> sample_star() {
    __Q++;
    if(__Q > MAX_CALLS) {
        std::cerr << "Too many sample_star() calls\n";
        exit(0);
    }

    static std::random_device rd;
    static std::mt19937 gen(rd());
    static std::uniform_int_distribution<> circle_dist(0, __K - 1);
    static std::uniform_real_distribution<> angle_dist(0, 2 * 3.14);

    int circle_idx = circle_dist(gen);

    const auto& circle = given_circles[circle_idx];
    double center_x = std::get<0>(circle);
    double center_y = std::get<1>(circle);
    double radius = std::get<2>(circle);

    double angle = angle_dist(gen);

    return {
        center_x + radius * std::cos(angle), center_y + radius * std::sin(angle)
    };
}

int main() {
    int K;
    std::cin >> K;
    for(int i = 0; i < K; i++) {
        double x, y, r;
        std::cin >> x >> y >> r;
        given_circles.push_back({x, y, r});
    }

    __K = K;
    solve(K);

    if(circles.size() != K) {
        std::cerr << "Wrong number of circles\n";
        std::cout << -1 << "\n";
        exit(0);
    }

    std::sort(circles.begin(), circles.end());
    std::sort(given_circles.begin(), given_circles.end());

    for(size_t i = 0; i < K; i++) {
        if(std::abs(std::get<0>(given_circles[i]) - std::get<0>(circles[i])) >
               1e-3 ||
           std::abs(std::get<1>(given_circles[i]) - std::get<1>(circles[i])) >
               1e-3 ||
           std::abs(std::get<2>(given_circles[i]) - std::get<2>(circles[i])) >
               1e-3) {
            std::cerr << "Circles don't match.\n";
            std::cout << "0.0\n";
            return 0;
        }
    }

    double score = 0.3 + 0.7 * pow(500.0 / std::max(__Q, 500), 0.5);

    std::cerr << "Correct answer with score:\n";
    std::cout << std::fixed << std::setprecision(10) << score << "\n";

    return 0;
}
/*
2
1123.75 -2410.12 528.9
-1500.123 300.1332 243.8
*/
